import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

//window size
const csvUrl =
  "https://gist.githubusercontent.com/RobFaj/21cdc1be72819954d22356da0c0dcb6e/raw/b4358836f13e05bcb433422dab8b45b7f0a68c07/ICE_6.csv"
const width = 960;
const height = 500;
const margin = { top: 10, right: 20, bottom: 50, left: 80 };


const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.month1_emplvl = +d['month1_emplvl'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 12)); // variables(columns) of data allowed
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;
 

  const yScale = scaleBand()
    .domain(data.map(d => d.qtr))
    .range([0, innerHeight])
		.padding(0.3);  //added padding
  
  const xScale = scaleLinear()
    .domain([0, max(data, d => d.month1_emplvl)])
    .range([0, innerWidth]);
  

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        
          //X-Axis design
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="red" />
            <text
              style={{ textAnchor: 'middle' }}
              dy="0.5em"
              y={innerHeight + 6}
            >
              {tickValue}
            </text>
          </g>
        ))}
        
        //Y-Axis design
        
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-20}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.qtr}
            x={1}
            y={yScale(d.qtr)}
            width={xScale(d.month1_emplvl)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);